package TinyJUnit;

import java.lang.annotation.Annotation;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.function.Predicate;

public class TinyJUnitDemo {
	
	/**
	 * This is my tiny approximation to JUnit.
	 *
	 * @param args This is the input from the console.
	 * @throws ClassNotFoundException We cannot find the class you want.
	 * @throws IllegalAccessException We cannot access the member.
	 * @throws IllegalArgumentException We offer wrong argument here.
	 * @throws InvocationTargetException We cannot invoke the target method.
	 */

	public static void main(String[] args) throws ClassNotFoundException {
		
		Class<?> clz = Class.forName("TinyJUnit.CalculatorTest");
//		Class<?> clz = Class.forName("TinyJUnit.PokerTest");
		
		List<Method> methods = Arrays.asList(clz.getDeclaredMethods());
		
		Predicate<Method> predicate = x -> {
			return Arrays.asList(x.getDeclaredAnnotations())
			             .stream()
	                     .anyMatch(item -> item.toString().contains("Test"));
		};
		
		methods.stream()
		       .filter(predicate)
		       .forEach(item -> {
					try {
						item.invoke(clz.newInstance());
						System.out.println(item + ": PASS");
					} catch (Exception e) {
						System.err.println(item + ": FAIL");
					}
		       });
		
	}

}
